==> aws-nuke-2.24.2.tar.gz: aws-nuke-2.24.2/resources/wafregional-byte-match-set-tuples.go <==
package resources

import (
	"github.com/aws/aws-sdk-go/aws"
	"github.com/aws/aws-sdk-go/aws/session"
	"github.com/aws/aws-sdk-go/service/waf"
	"github.com/aws/aws-sdk-go/service/wafregional"
	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
)

type WAFRegionalByteMatchSetIP struct {
	svc        *wafregional.WAFRegional
	matchSetid *string
	tuple      *waf.ByteMatchTuple
}

func init() {
	register("WAFRegionalByteMatchSetIP", ListWAFRegionalByteMatchSetIPs)
}

func ListWAFRegionalByteMatchSetIPs(sess *session.Session) ([]Resource, error) {
	svc := wafregional.New(sess)
	resources := []Resource{}

	params := &waf.ListByteMatchSetsInput{
		Limit: aws.Int64(50),
	}

	for {
		resp, err := svc.ListByteMatchSets(params)
		if err != nil {
			return nil, err
		}

		for _, set := range resp.ByteMatchSets {

			details, err := svc.GetByteMatchSet(&waf.GetByteMatchSetInput{
				ByteMatchSetId: set.ByteMatchSetId,
			})
			if err != nil {
				return nil, err
			}

			for _, tuple := range details.ByteMatchSet.ByteMatchTuples {
				resources = append(resources, &WAFRegionalByteMatchSetIP{
					svc:        svc,
					matchSetid: set.ByteMatchSetId,
					tuple:      tuple,
				})
			}
		}

		if resp.NextMarker == nil {
			break
		}

		params.NextMarker = resp.NextMarker
	}

	return resources, nil
}

func (r *WAFRegionalByteMatchSetIP) Remove() error {
	tokenOutput, err := r.svc.GetChangeToken(&waf.GetChangeTokenInput{})
	if err != nil {
		return err
	}

	_, err = r.svc.UpdateByteMatchSet(&waf.UpdateByteMatchSetInput{
		ChangeToken:    tokenOutput.ChangeToken,
		ByteMatchSetId: r.matchSetid,
		Updates: []*waf.ByteMatchSetUpdate{
			{
				Action:         aws.String("DELETE"),
				ByteMatchTuple: r.tuple,
			},
		},
	})

	return err
}

func (r *WAFRegionalByteMatchSetIP) Properties() types.Properties {
	return types.NewProperties().
		Set("ByteMatchSetID", r.matchSetid).
		Set("FieldToMatchType", r.tuple.FieldToMatch.Type).
		Set("FieldToMatchData", r.tuple.FieldToMatch.Data).
		Set("TargetString", r.tuple.TargetString)
}

==> aws-nuke-3.56.2.tar.gz: aws-nuke-3.56.2/resources/wafregional-byte-match-set-tuples.go <==
package resources

import (
	"context"

	"github.com/aws/aws-sdk-go/aws"
	"github.com/aws/aws-sdk-go/service/waf"
	"github.com/aws/aws-sdk-go/service/wafregional"

	"github.com/ekristen/libnuke/pkg/registry"
	"github.com/ekristen/libnuke/pkg/resource"
	"github.com/ekristen/libnuke/pkg/types"

	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
)

const WAFRegionalByteMatchSetIPResource = "WAFRegionalByteMatchSetIP"

func init() {
	registry.Register(&registry.Registration{
		Name:     WAFRegionalByteMatchSetIPResource,
		Scope:    nuke.Account,
		Resource: &WAFRegionalByteMatchSetIP{},
		Lister:   &WAFRegionalByteMatchSetIPLister{},
	})
}

type WAFRegionalByteMatchSetIPLister struct{}

func (l *WAFRegionalByteMatchSetIPLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
	opts := o.(*nuke.ListerOpts)

	svc := wafregional.New(opts.Session)
	resources := make([]resource.Resource, 0)

	params := &waf.ListByteMatchSetsInput{
		Limit: aws.Int64(50),
	}

	for {
		resp, err := svc.ListByteMatchSets(params)
		if err != nil {
			return nil, err
		}

		for _, set := range resp.ByteMatchSets {
			details, err := svc.GetByteMatchSet(&waf.GetByteMatchSetInput{
				ByteMatchSetId: set.ByteMatchSetId,
			})
			if err != nil {
				return nil, err
			}

			for _, tuple := range details.ByteMatchSet.ByteMatchTuples {
				resources = append(resources, &WAFRegionalByteMatchSetIP{
					svc:        svc,
					matchSetID: set.ByteMatchSetId,
					tuple:      tuple,
				})
			}
		}

		if resp.NextMarker == nil {
			break
		}

		params.NextMarker = resp.NextMarker
	}

	return resources, nil
}

type WAFRegionalByteMatchSetIP struct {
	svc        *wafregional.WAFRegional
	matchSetID *string
	tuple      *waf.ByteMatchTuple
}

func (r *WAFRegionalByteMatchSetIP) Remove(_ context.Context) error {
	tokenOutput, err := r.svc.GetChangeToken(&waf.GetChangeTokenInput{})
	if err != nil {
		return err
	}

	_, err = r.svc.UpdateByteMatchSet(&waf.UpdateByteMatchSetInput{
		ChangeToken:    tokenOutput.ChangeToken,
		ByteMatchSetId: r.matchSetID,
		Updates: []*waf.ByteMatchSetUpdate{
			{
				Action:         aws.String("DELETE"),
				ByteMatchTuple: r.tuple,
			},
		},
	})

	return err
}

func (r *WAFRegionalByteMatchSetIP) Properties() types.Properties {
	return types.NewProperties().
		Set("ByteMatchSetID", r.matchSetID).
		Set("FieldToMatchType", r.tuple.FieldToMatch.Type).
		Set("FieldToMatchData", r.tuple.FieldToMatch.Data).
		Set("TargetString", r.tuple.TargetString)
}
